"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = void 0;

var _react = _interopRequireWildcard(require("react"));

var _propTypes = _interopRequireDefault(require("prop-types"));

var _immutable = _interopRequireDefault(require("immutable"));

var _reactIntl = require("react-intl");

var _get = _interopRequireDefault(require("lodash/get"));

var _recordDataHelpers = require("../../helpers/recordDataHelpers");

var _RecordFormContainer = _interopRequireDefault(require("../../containers/record/RecordFormContainer"));

var _InvocationEditor = _interopRequireDefault(require("../../../styles/cspace-ui/InvocationEditor.css"));

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

function _interopRequireWildcard(obj) { if (obj && obj.__esModule) { return obj; } else { var newObj = {}; if (obj != null) { for (var key in obj) { if (Object.prototype.hasOwnProperty.call(obj, key)) { var desc = Object.defineProperty && Object.getOwnPropertyDescriptor ? Object.getOwnPropertyDescriptor(obj, key) : {}; if (desc.get || desc.set) { Object.defineProperty(newObj, key, desc); } else { newObj[key] = obj[key]; } } } } newObj.default = obj; return newObj; } }

const messages = (0, _reactIntl.defineMessages)({
  loading: {
    "id": "invocationEditor.loading",
    "defaultMessage": "Loading\u2026"
  },
  noDescription: {
    "id": "invocationEditor.noDescription",
    "defaultMessage": "Description not provided."
  }
});

const renderLoading = () => _react.default.createElement("div", {
  className: _InvocationEditor.default.pending
}, _react.default.createElement(_reactIntl.FormattedMessage, messages.loading));

const propTypes = {
  config: _propTypes.default.object,
  metadata: _propTypes.default.instanceOf(_immutable.default.Map),
  paramData: _propTypes.default.instanceOf(_immutable.default.Map),
  recordType: _propTypes.default.string,
  createNewRecord: _propTypes.default.func
};

class InvocationEditor extends _react.Component {
  componentDidMount() {
    this.initRecord();
  }

  componentDidUpdate(prevProps) {
    if (prevProps.metadata !== this.props.metadata) {
      this.initRecord();
    }
  }

  initRecord() {
    const {
      createNewRecord
    } = this.props;
    createNewRecord();
  }

  render() {
    const {
      config,
      metadata,
      paramData,
      recordType
    } = this.props;

    if (!metadata) {
      return renderLoading();
    }

    const invocableNameGetter = (0, _get.default)(config, ['recordTypes', recordType, 'invocableName']);
    const invocableName = invocableNameGetter && invocableNameGetter(metadata);
    const paramRecordTypeConfig = (0, _get.default)(config, ['invocables', recordType, invocableName]);

    const description = (0, _recordDataHelpers.getCommonFieldValue)(metadata, 'notes') || _react.default.createElement(_reactIntl.FormattedMessage, messages.noDescription);

    return _react.default.createElement("div", {
      className: _InvocationEditor.default.common
    }, _react.default.createElement("p", null, description), _react.default.createElement(_RecordFormContainer.default, {
      config: config,
      csid: "",
      data: paramData,
      recordType: "invocable",
      recordTypeConfig: paramRecordTypeConfig
    }));
  }

}

exports.default = InvocationEditor;
InvocationEditor.propTypes = propTypes;