"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = void 0;

var _react = _interopRequireWildcard(require("react"));

var _propTypes = _interopRequireDefault(require("prop-types"));

var _reactIntl = require("react-intl");

var _immutable = _interopRequireDefault(require("immutable"));

var _get = _interopRequireDefault(require("lodash/get"));

var _cspaceLayout = require("cspace-layout");

var _InvokeButton = _interopRequireDefault(require("./InvokeButton"));

var _InvocationEditorContainer = _interopRequireDefault(require("../../containers/invocable/InvocationEditorContainer"));

var _CancelButton = _interopRequireDefault(require("../navigation/CancelButton"));

var _InvocationModal = _interopRequireDefault(require("../../../styles/cspace-ui/InvocationModal.css"));

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

function _interopRequireWildcard(obj) { if (obj && obj.__esModule) { return obj; } else { var newObj = {}; if (obj != null) { for (var key in obj) { if (Object.prototype.hasOwnProperty.call(obj, key)) { var desc = Object.defineProperty && Object.getOwnPropertyDescriptor ? Object.getOwnPropertyDescriptor(obj, key) : {}; if (desc.get || desc.set) { Object.defineProperty(newObj, key, desc); } else { newObj[key] = obj[key]; } } } } newObj.default = obj; return newObj; } }

const messages = (0, _reactIntl.defineMessages)({
  cancel: {
    "id": "invocationModal.cancel",
    "defaultMessage": "Cancel"
  },
  invoke: {
    "id": "invocationModal.run",
    "defaultMessage": "Run"
  }
});
const propTypes = {
  config: _propTypes.default.object.isRequired,
  csid: _propTypes.default.string,
  data: _propTypes.default.instanceOf(_immutable.default.Map),
  initialInvocationDescriptor: _propTypes.default.shape({
    csid: _propTypes.default.oneOfType([_propTypes.default.string, _propTypes.default.arrayOf(_propTypes.default.string)]),
    recordType: _propTypes.default.string
  }),
  isOpen: _propTypes.default.bool,
  isRecordModified: _propTypes.default.bool,
  recordType: _propTypes.default.oneOf(['report', 'batch']),
  readRecord: _propTypes.default.func,
  onCancelButtonClick: _propTypes.default.func,
  onCloseButtonClick: _propTypes.default.func,
  onInvokeButtonClick: _propTypes.default.func
};

class InvocationModal extends _react.Component {
  constructor() {
    super();
    this.handleInvokeButtonClick = this.handleInvokeButtonClick.bind(this);
    this.renderButtonBar = this.renderButtonBar.bind(this);
  }

  componentDidUpdate(prevProps) {
    const {
      csid,
      isOpen,
      readRecord
    } = this.props;
    const {
      csid: prevCsid
    } = prevProps;

    if (csid && csid !== prevCsid && isOpen && readRecord) {
      readRecord();
    }
  }

  handleInvokeButtonClick() {
    const {
      data,
      initialInvocationDescriptor,
      onInvokeButtonClick
    } = this.props;

    if (onInvokeButtonClick) {
      onInvokeButtonClick(data, initialInvocationDescriptor);
    }
  }

  renderButtonBar() {
    const {
      onCancelButtonClick,
      recordType
    } = this.props;
    return _react.default.createElement("div", null, _react.default.createElement(_CancelButton.default, {
      label: _react.default.createElement(_reactIntl.FormattedMessage, messages.cancel),
      onClick: onCancelButtonClick
    }), _react.default.createElement(_InvokeButton.default, {
      label: _react.default.createElement(_reactIntl.FormattedMessage, messages.invoke),
      recordType: recordType,
      onClick: this.handleInvokeButtonClick
    }));
  }

  renderTitle() {
    const {
      config,
      data,
      recordType
    } = this.props;

    if (!data) {
      return ' ';
    }

    const recordTypeConfig = (0, _get.default)(config, ['recordTypes', recordType]);
    const titleGetter = (0, _get.default)(recordTypeConfig, 'title');
    let title = titleGetter && titleGetter(data);

    if (!title) {
      const recordTypeMessages = (0, _get.default)(recordTypeConfig, ['messages', 'record']);
      title = _react.default.createElement(_reactIntl.FormattedMessage, recordTypeMessages.name);
    }

    return _react.default.createElement("h1", null, title);
  }

  render() {
    const {
      config,
      csid,
      data,
      isOpen,
      isRecordModified,
      recordType,
      onCloseButtonClick
    } = this.props;

    if (!isOpen || !csid) {
      return null;
    }

    const recordTypeConfig = (0, _get.default)(config, ['recordTypes', recordType]);
    const recordTypeMessages = (0, _get.default)(recordTypeConfig, ['messages', 'record']);
    const invocableNameGetter = (0, _get.default)(recordTypeConfig, 'invocableName');
    const invocableName = invocableNameGetter && invocableNameGetter(data);
    let unsavedWarning;

    if (isRecordModified) {
      unsavedWarning = _react.default.createElement("p", null, _react.default.createElement(_reactIntl.FormattedMessage, recordTypeMessages.invokeUnsaved));
    }

    return _react.default.createElement(_cspaceLayout.Modal, {
      className: _InvocationModal.default.common,
      isOpen: isOpen,
      title: this.renderTitle(),
      closeButtonClassName: "material-icons",
      closeButtonLabel: "close",
      renderButtonBar: this.renderButtonBar,
      onCloseButtonClick: onCloseButtonClick
    }, unsavedWarning, _react.default.createElement(_InvocationEditorContainer.default, {
      config: config,
      metadata: data,
      invocableName: invocableName,
      recordType: recordType
    }));
  }

}

exports.default = InvocationModal;
InvocationModal.modalName = 'InvocationModal';
InvocationModal.propTypes = propTypes;