"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = exports.BaseSearchToRelateModal = exports.searchName = void 0;

var _react = _interopRequireWildcard(require("react"));

var _propTypes = _interopRequireDefault(require("prop-types"));

var _reactIntl = require("react-intl");

var _immutable = _interopRequireDefault(require("immutable"));

var _get = _interopRequireDefault(require("lodash/get"));

var _isEqual = _interopRequireDefault(require("lodash/isEqual"));

var _cspaceLayout = require("cspace-layout");

var _CheckboxInput = _interopRequireDefault(require("cspace-input/lib/components/CheckboxInput"));

var _SearchForm = _interopRequireDefault(require("./SearchForm"));

var _Pager = _interopRequireDefault(require("./Pager"));

var _BackButton = _interopRequireDefault(require("../navigation/BackButton"));

var _CancelButton = _interopRequireDefault(require("../navigation/CancelButton"));

var _RelateButton = _interopRequireDefault(require("../record/RelateButton"));

var _SearchButton = _interopRequireDefault(require("./SearchButton"));

var _SearchClearButton = _interopRequireDefault(require("./SearchClearButton"));

var _SearchResultSummary = _interopRequireDefault(require("./SearchResultSummary"));

var _SearchToRelateTitleBar = _interopRequireDefault(require("./SearchToRelateTitleBar"));

var _SelectBar = _interopRequireDefault(require("./SelectBar"));

var _SearchResultTableContainer = _interopRequireDefault(require("../../containers/search/SearchResultTableContainer"));

var _configHelpers = require("../../helpers/configHelpers");

var _permissionHelpers = require("../../helpers/permissionHelpers");

var _searchHelpers = require("../../helpers/searchHelpers");

var _SearchToRelateModal = _interopRequireDefault(require("../../../styles/cspace-ui/SearchToRelateModal.css"));

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

function _interopRequireWildcard(obj) { if (obj && obj.__esModule) { return obj; } else { var newObj = {}; if (obj != null) { for (var key in obj) { if (Object.prototype.hasOwnProperty.call(obj, key)) { var desc = Object.defineProperty && Object.getOwnPropertyDescriptor ? Object.getOwnPropertyDescriptor(obj, key) : {}; if (desc.get || desc.set) { Object.defineProperty(newObj, key, desc); } else { newObj[key] = obj[key]; } } } } newObj.default = obj; return newObj; } }

const messages = (0, _reactIntl.defineMessages)({
  editSearch: {
    "id": "searchToRelateModal.editSearch",
    "defaultMessage": "Revise search"
  },
  label: {
    "id": "searchToRelateModal.label",
    "defaultMessage": "Relate"
  },
  relate: {
    "id": "searchToRelateModal.relate",
    "defaultMessage": "Relate selected"
  },
  relating: {
    "id": "searchToRelateModal.relating",
    "defaultMessage": "Relating..."
  },
  multipleSubjectsRelated: {
    "id": "searchToRelateModal.multipleSubjectsRelated",
    "defaultMessage": "{objectCount, plural, =0 {No records} one {# record} other {# records}} related to each of {subjectCount, number} search results."
  }
});
const searchName = 'searchToRelate';
exports.searchName = searchName;
const listType = 'common'; // FIXME: Make default page size configurable

const defaultPageSize = 20;

const isSingleSubject = subjects => Array.isArray(subjects) && subjects.length === 1;

const propTypes = {
  allowedServiceTypes: _propTypes.default.arrayOf(_propTypes.default.string),
  config: _propTypes.default.object,
  intl: _reactIntl.intlShape,
  isOpen: _propTypes.default.bool,
  keywordValue: _propTypes.default.string,
  defaultRecordTypeValue: _propTypes.default.string,
  recordTypeValue: _propTypes.default.string,
  vocabularyValue: _propTypes.default.string,
  advancedSearchCondition: _propTypes.default.object,
  preferredAdvancedSearchBooleanOp: _propTypes.default.string,
  preferredPageSize: _propTypes.default.number,
  perms: _propTypes.default.instanceOf(_immutable.default.Map),
  selectedItems: _propTypes.default.instanceOf(_immutable.default.Map),
  subjects: _propTypes.default.oneOfType([_propTypes.default.arrayOf(_propTypes.default.shape({
    /* eslint-disable react/no-unused-prop-types */
    csid: _propTypes.default.string,
    recordType: _propTypes.default.string
    /* eslint-enable react/no-unused-prop-types */

  })), _propTypes.default.func]),
  getAuthorityVocabCsid: _propTypes.default.func,
  onAdvancedSearchConditionCommit: _propTypes.default.func,
  onKeywordCommit: _propTypes.default.func,
  onRecordTypeCommit: _propTypes.default.func,
  onVocabularyCommit: _propTypes.default.func,
  onCloseButtonClick: _propTypes.default.func,
  onCancelButtonClick: _propTypes.default.func,
  onClearButtonClick: _propTypes.default.func,
  onItemSelectChange: _propTypes.default.func,
  onRelationsCreated: _propTypes.default.func,
  clearSearchResults: _propTypes.default.func,
  createRelations: _propTypes.default.func,
  parentSelector: _propTypes.default.func,
  search: _propTypes.default.func,
  setAllItemsSelected: _propTypes.default.func,
  setPreferredPageSize: _propTypes.default.func,
  showRelationNotification: _propTypes.default.func
};
const defaultProps = {
  selectedItems: _immutable.default.Map()
};

class BaseSearchToRelateModal extends _react.Component {
  constructor() {
    super();
    this.shouldShowCheckbox = this.shouldShowCheckbox.bind(this);
    this.handleAcceptButtonClick = this.handleAcceptButtonClick.bind(this);
    this.handleCancelButtonClick = this.handleCancelButtonClick.bind(this);
    this.handleCheckboxCommit = this.handleCheckboxCommit.bind(this);
    this.handleCloseButtonClick = this.handleCloseButtonClick.bind(this);
    this.handleEditSearchLinkClick = this.handleEditSearchLinkClick.bind(this);
    this.handleFormSearch = this.handleFormSearch.bind(this);
    this.handlePageChange = this.handlePageChange.bind(this);
    this.handlePageSizeChange = this.handlePageSizeChange.bind(this);
    this.handleSortChange = this.handleSortChange.bind(this);
    this.renderCheckbox = this.renderCheckbox.bind(this);
    this.renderEditSearchLink = this.renderEditSearchLink.bind(this);
    this.renderModalButtonBar = this.renderModalButtonBar.bind(this);
    this.renderSearchResultTableHeader = this.renderSearchResultTableHeader.bind(this);
    this.renderSearchResultTableFooter = this.renderSearchResultTableFooter.bind(this);
    this.state = {
      isSearchInitiated: false,
      pageNum: 0,
      sort: null
    };
  }

  componentWillReceiveProps(nextProps) {
    const {
      isOpen
    } = this.props;
    const {
      isOpen: nextIsOpen
    } = nextProps;

    if (isOpen && !nextIsOpen) {
      // Closing.
      this.setState({
        isRelating: false,
        isSearchInitiated: false,
        pageNum: 0,
        sort: null
      });
    }
  }

  componentDidUpdate(prevProps, prevState) {
    const {
      isOpen
    } = this.props;
    const {
      isOpen: prevIsOpen
    } = prevProps;

    if (prevIsOpen && !isOpen) {
      // Closed.
      const {
        clearSearchResults,
        onRecordTypeCommit
      } = this.props;

      if (clearSearchResults) {
        clearSearchResults(searchName);
      }

      if (onRecordTypeCommit) {
        onRecordTypeCommit('');
      }
    } else if (!prevIsOpen && isOpen) {
      // Opened.
      const {
        defaultRecordTypeValue,
        onRecordTypeCommit
      } = this.props;

      if (onRecordTypeCommit) {
        onRecordTypeCommit(defaultRecordTypeValue); // TODO: If search to relate is ever used on authorities, need to set the default vocabulary
        // if this is an authority record type, and vocabularyValue is not provided.
      }
    }

    const {
      isSearchInitiated,
      pageNum,
      sort
    } = this.state;

    if (isSearchInitiated) {
      const {
        recordTypeValue,
        vocabularyValue,
        advancedSearchCondition,
        preferredPageSize
      } = this.props;
      const {
        recordTypeValue: prevRecordTypeValue,
        vocabularyValue: prevVocabularyValue,
        advancedSearchCondition: prevAdvancedSearchCondition,
        preferredPageSize: prevPreferredPageSize
      } = prevProps;
      const {
        pageNum: prevPageNum,
        sort: prevSort
      } = prevState;

      if (recordTypeValue !== prevRecordTypeValue || vocabularyValue !== prevVocabularyValue || !(0, _isEqual.default)(advancedSearchCondition, prevAdvancedSearchCondition) || preferredPageSize !== prevPreferredPageSize || pageNum !== prevPageNum || sort !== prevSort) {
        this.search();
      }
    }
  }

  getSearchDescriptor() {
    const {
      config,
      recordTypeValue: recordType,
      vocabularyValue: vocabulary,
      keywordValue: keyword,
      advancedSearchCondition,
      preferredPageSize,
      subjects
    } = this.props;
    const {
      pageNum,
      sort
    } = this.state;
    const pageSize = preferredPageSize || defaultPageSize;
    const searchQuery = {
      p: pageNum,
      size: pageSize
    };

    if (isSingleSubject(subjects)) {
      searchQuery.mkRtSbj = subjects[0].csid;
    }

    if (sort) {
      searchQuery.sort = sort;
    }

    const kw = keyword ? keyword.trim() : '';

    if (kw) {
      searchQuery.kw = kw;
    }

    const fields = (0, _get.default)(config, ['recordTypes', recordType, 'fields']);
    const condition = (0, _searchHelpers.normalizeCondition)(fields, advancedSearchCondition);

    if (condition) {
      searchQuery.as = condition;
    }

    return _immutable.default.fromJS({
      recordType,
      vocabulary,
      searchQuery
    });
  }

  relate() {
    const {
      selectedItems,
      createRelations,
      onRelationsCreated
    } = this.props;

    if (createRelations) {
      let {
        subjects
      } = this.props;

      if (typeof subjects === 'function') {
        subjects = subjects();
      }

      if (subjects && subjects.length > 0) {
        const searchDescriptor = this.getSearchDescriptor();
        this.setState({
          isRelating: true,
          isSearchInitiated: false
        });
        const objects = selectedItems.valueSeq().map(item => ({
          csid: item.get('csid'),
          recordType: searchDescriptor.get('recordType')
        })).toJS();
        Promise.all(subjects.map(subject => createRelations(subject, objects, 'affects'))).then(() => {
          if (subjects.length > 1) {
            const {
              showRelationNotification
            } = this.props;

            if (showRelationNotification) {
              showRelationNotification(messages.multipleSubjectsRelated, {
                objectCount: objects.length,
                subjectCount: subjects.length
              });
            }
          }

          if (onRelationsCreated) {
            onRelationsCreated();
          }
        });
      }
    }
  }

  search() {
    const {
      config,
      search
    } = this.props;

    if (search) {
      const searchDescriptor = this.getSearchDescriptor();
      search(config, searchName, searchDescriptor);
      this.setState({
        isSearchInitiated: true
      });
    }
  }

  handleAcceptButtonClick() {
    const {
      isSearchInitiated
    } = this.state;

    if (isSearchInitiated) {
      this.relate();
    } else {
      this.search();
    }
  }

  handleCancelButtonClick(event) {
    const {
      onCancelButtonClick
    } = this.props;

    if (onCancelButtonClick) {
      onCancelButtonClick(event);
    }
  }

  handleCloseButtonClick(event) {
    const {
      onCloseButtonClick
    } = this.props;

    if (onCloseButtonClick) {
      onCloseButtonClick(event);
    }
  }

  handleEditSearchLinkClick() {
    const {
      clearSearchResults
    } = this.props;

    if (clearSearchResults) {
      clearSearchResults(searchName);
    }

    this.setState({
      isSearchInitiated: false
    });
  }

  handleFormSearch() {
    this.search();
  }

  handleCheckboxCommit(path, value) {
    const index = parseInt(path[0], 10);
    const checked = value;
    const {
      config,
      onItemSelectChange
    } = this.props;

    if (onItemSelectChange) {
      const searchDescriptor = this.getSearchDescriptor();
      onItemSelectChange(config, searchName, searchDescriptor, listType, index, checked);
    }
  }

  handlePageChange(pageNum) {
    this.setState({
      pageNum
    });
  }

  handlePageSizeChange(pageSize) {
    const {
      setPreferredPageSize
    } = this.props;
    let normalizedPageSize;

    if (isNaN(pageSize) || pageSize < 1) {
      normalizedPageSize = 0;
    } else if (pageSize > 2500) {
      normalizedPageSize = 2500;
    } else {
      normalizedPageSize = pageSize;
    }

    if (setPreferredPageSize) {
      this.setState({
        pageNum: 0
      });
      setPreferredPageSize(normalizedPageSize);
    }
  }

  handleSortChange(sort) {
    this.setState({
      sort
    });
  }

  shouldShowCheckbox(item) {
    if (item.get('workflowState') === 'locked') {
      return false;
    }

    if (item.get('related') === 'true') {
      return false;
    }

    const {
      config,
      perms,
      subjects
    } = this.props;

    if (isSingleSubject(subjects) && item.get('csid') === subjects[0].csid) {
      return false;
    }

    return (0, _permissionHelpers.canRelate)((0, _configHelpers.getRecordTypeNameByUri)(config, item.get('uri')), perms, config);
  }

  renderCheckbox(_ref) {
    let {
      rowData,
      rowIndex
    } = _ref;

    if (this.shouldShowCheckbox(rowData)) {
      const {
        selectedItems
      } = this.props;
      const itemCsid = rowData.get('csid');
      const selected = selectedItems ? selectedItems.has(itemCsid) : false;
      return _react.default.createElement(_CheckboxInput.default, {
        embedded: true,
        name: "".concat(rowIndex),
        value: selected,
        onCommit: this.handleCheckboxCommit
      });
    }

    return null;
  }

  renderSearchForm() {
    const {
      allowedServiceTypes,
      config,
      intl,
      keywordValue,
      recordTypeValue,
      vocabularyValue,
      perms,
      preferredAdvancedSearchBooleanOp,
      advancedSearchCondition,
      getAuthorityVocabCsid,
      onAdvancedSearchConditionCommit,
      onKeywordCommit,
      onRecordTypeCommit,
      onVocabularyCommit
    } = this.props;
    let recordTypeInputReadOnly = true;
    let recordTypeInputRootType;

    if (allowedServiceTypes) {
      // Allow the record type to be changed.
      recordTypeInputReadOnly = false; // Don't show the All Records option.

      recordTypeInputRootType = '';
    }

    return _react.default.createElement(_SearchForm.default, {
      config: config,
      intl: intl,
      recordTypeValue: recordTypeValue,
      vocabularyValue: vocabularyValue,
      keywordValue: keywordValue,
      advancedSearchCondition: advancedSearchCondition,
      perms: perms,
      preferredAdvancedSearchBooleanOp: preferredAdvancedSearchBooleanOp,
      recordTypeInputReadOnly: recordTypeInputReadOnly,
      recordTypeInputRootType: recordTypeInputRootType,
      recordTypeInputServiceTypes: allowedServiceTypes,
      getAuthorityVocabCsid: getAuthorityVocabCsid,
      onAdvancedSearchConditionCommit: onAdvancedSearchConditionCommit,
      onKeywordCommit: onKeywordCommit,
      onRecordTypeCommit: onRecordTypeCommit,
      onVocabularyCommit: onVocabularyCommit,
      onSearch: this.handleFormSearch
    });
  }

  renderEditSearchLink() {
    return _react.default.createElement("button", {
      onClick: this.handleEditSearchLinkClick
    }, _react.default.createElement(_reactIntl.FormattedMessage, messages.editSearch));
  }

  renderSearchResultTableHeader(_ref2) {
    let {
      searchError,
      searchResult
    } = _ref2;
    const {
      config,
      selectedItems,
      setAllItemsSelected
    } = this.props;

    if (searchError) {
      return null;
    }

    const searchDescriptor = this.getSearchDescriptor();
    return _react.default.createElement("header", null, _react.default.createElement(_SearchResultSummary.default, {
      config: config,
      listType: listType,
      searchDescriptor: searchDescriptor,
      searchError: searchError,
      searchResult: searchResult,
      renderEditLink: this.renderEditSearchLink,
      onPageSizeChange: this.handlePageSizeChange
    }), _react.default.createElement(_SelectBar.default, {
      config: config,
      listType: listType,
      searchDescriptor: searchDescriptor,
      searchName: searchName,
      searchResult: searchResult,
      selectedItems: selectedItems,
      setAllItemsSelected: setAllItemsSelected,
      showCheckboxFilter: this.shouldShowCheckbox
    }));
  }

  renderSearchResultTableFooter(_ref3) {
    let {
      searchResult
    } = _ref3;
    const {
      config
    } = this.props;

    if (searchResult) {
      const listTypeConfig = config.listTypes[listType];
      const list = searchResult.get(listTypeConfig.listNodeName);
      const totalItems = parseInt(list.get('totalItems'), 10);
      const pageSize = parseInt(list.get('pageSize'), 10);
      const pageNum = parseInt(list.get('pageNum'), 10);
      const lastPage = Math.max(0, isNaN(totalItems) ? 0 : Math.ceil(totalItems / pageSize) - 1);
      return _react.default.createElement("footer", null, _react.default.createElement(_Pager.default, {
        currentPage: pageNum,
        lastPage: lastPage,
        pageSize: pageSize,
        onPageChange: this.handlePageChange,
        onPageSizeChange: this.handlePageSizeChange
      }));
    }

    return null;
  }

  renderSearchResultTable() {
    const {
      config,
      recordTypeValue
    } = this.props;
    const searchDescriptor = this.getSearchDescriptor();
    return _react.default.createElement(_SearchResultTableContainer.default, {
      config: config,
      linkItems: false,
      listType: listType,
      recordType: recordTypeValue,
      searchName: searchName,
      searchDescriptor: searchDescriptor,
      showCheckboxColumn: true,
      renderCheckbox: this.renderCheckbox,
      renderHeader: this.renderSearchResultTableHeader,
      renderFooter: this.renderSearchResultTableFooter,
      onSortChange: this.handleSortChange
    });
  }

  renderModalButtonBar() {
    const {
      selectedItems,
      onClearButtonClick
    } = this.props;
    const {
      isRelating,
      isSearchInitiated
    } = this.state;

    const cancelButton = _react.default.createElement(_CancelButton.default, {
      disabled: isRelating,
      onClick: this.handleCancelButtonClick
    });

    let acceptButton;
    let backButton;
    let clearButton;

    if (isSearchInitiated) {
      acceptButton = _react.default.createElement(_RelateButton.default, {
        disabled: isRelating || !selectedItems || selectedItems.size < 1,
        label: _react.default.createElement(_reactIntl.FormattedMessage, messages.relate),
        onClick: this.handleAcceptButtonClick
      });
      backButton = _react.default.createElement(_BackButton.default, {
        disabled: isRelating,
        label: _react.default.createElement(_reactIntl.FormattedMessage, messages.editSearch),
        onClick: this.handleEditSearchLinkClick
      });
    } else {
      acceptButton = _react.default.createElement(_SearchButton.default, {
        disabled: isRelating,
        type: "button",
        onClick: this.handleAcceptButtonClick
      });
      clearButton = _react.default.createElement(_SearchClearButton.default, {
        onClick: onClearButtonClick
      });
    }

    return _react.default.createElement("div", null, cancelButton, clearButton, backButton, acceptButton);
  }

  render() {
    const {
      config,
      intl,
      isOpen,
      recordTypeValue,
      parentSelector
    } = this.props;
    const {
      isRelating,
      isSearchInitiated
    } = this.state;
    let content;

    if (isRelating) {
      content = _react.default.createElement("p", null, _react.default.createElement(_reactIntl.FormattedMessage, messages.relating));
    } else if (isSearchInitiated) {
      content = this.renderSearchResultTable();
    } else {
      content = this.renderSearchForm();
    }

    const searchDescriptor = this.getSearchDescriptor();

    const title = _react.default.createElement(_SearchToRelateTitleBar.default, {
      config: config,
      isSearchInitiated: isSearchInitiated,
      recordType: recordTypeValue,
      searchDescriptor: searchDescriptor
    });

    return _react.default.createElement(_cspaceLayout.Modal, {
      className: _SearchToRelateModal.default.common,
      contentLabel: intl.formatMessage(messages.label),
      title: title,
      isOpen: isOpen,
      showCloseButton: !isRelating,
      closeButtonClassName: "material-icons",
      closeButtonLabel: "close",
      parentSelector: parentSelector,
      renderButtonBar: this.renderModalButtonBar,
      onCloseButtonClick: this.handleCloseButtonClick
    }, content);
  }

}

exports.BaseSearchToRelateModal = BaseSearchToRelateModal;
BaseSearchToRelateModal.propTypes = propTypes;
BaseSearchToRelateModal.defaultProps = defaultProps;

var _default = (0, _reactIntl.injectIntl)(BaseSearchToRelateModal);

exports.default = _default;