"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = SearchToRelateTitleBar;

var _react = _interopRequireDefault(require("react"));

var _propTypes = _interopRequireDefault(require("prop-types"));

var _reactIntl = require("react-intl");

var _get = _interopRequireDefault(require("lodash/get"));

var _immutable = _interopRequireDefault(require("immutable"));

var _AdvancedSearchBuilder = _interopRequireDefault(require("./AdvancedSearchBuilder"));

var _SearchToRelateTitleBar = _interopRequireDefault(require("../../../styles/cspace-ui/SearchToRelateTitleBar.css"));

var _Subtitle = _interopRequireDefault(require("../../../styles/cspace-ui/Subtitle.css"));

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

function _extends() { _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; }; return _extends.apply(this, arguments); }

const messages = (0, _reactIntl.defineMessages)({
  title: {
    "id": "searchToRelateTitleBar.title",
    "defaultMessage": "Relate {collectionName} {query}"
  },
  keyword: {
    "id": "searchToRelateTitleBar.keyword",
    "defaultMessage": "containing {keyword}"
  }
});
const propTypes = {
  config: _propTypes.default.object,
  isSearchInitiated: _propTypes.default.bool,
  recordType: _propTypes.default.string,
  vocabulary: _propTypes.default.string,
  searchDescriptor: _propTypes.default.instanceOf(_immutable.default.Map)
};

function SearchToRelateTitleBar(props) {
  const {
    config,
    isSearchInitiated,
    searchDescriptor
  } = props;
  let collectionName;

  if (!isSearchInitiated) {
    const {
      recordType,
      vocabulary
    } = props;
    const recordTypeConfig = (0, _get.default)(config, ['recordTypes', recordType]);

    if (!recordTypeConfig) {
      return null;
    }

    const vocabularyConfig = vocabulary ? (0, _get.default)(recordTypeConfig, ['vocabularies', vocabulary]) : undefined;

    if (vocabularyConfig) {
      collectionName = _react.default.createElement(_reactIntl.FormattedMessage, vocabularyConfig.messages.collectionName);
    } else {
      collectionName = _react.default.createElement(_reactIntl.FormattedMessage, recordTypeConfig.messages.record.collectionName);
    }

    return _react.default.createElement("header", {
      className: _SearchToRelateTitleBar.default.common
    }, _react.default.createElement("h1", null, _react.default.createElement(_reactIntl.FormattedMessage, _extends({}, messages.title, {
      values: {
        collectionName,
        query: ''
      }
    }))));
  }

  const recordType = searchDescriptor.get('recordType');
  const vocabulary = searchDescriptor.get('vocabulary');
  const recordTypeConfig = (0, _get.default)(config, ['recordTypes', recordType]);
  const vocabularyConfig = vocabulary ? (0, _get.default)(recordTypeConfig, ['vocabularies', vocabulary]) : undefined;
  const searchQuery = searchDescriptor.get('searchQuery');
  const advancedSearchCondition = searchQuery.get('as');
  const kw = searchQuery.get('kw');
  const queryTitle = kw ? _react.default.createElement(_reactIntl.FormattedMessage, _extends({}, messages.keyword, {
    values: {
      keyword: kw
    }
  })) : null;

  if (vocabularyConfig) {
    collectionName = _react.default.createElement(_reactIntl.FormattedMessage, vocabularyConfig.messages.collectionName);
  } else {
    collectionName = _react.default.createElement(_reactIntl.FormattedMessage, recordTypeConfig.messages.record.collectionName);
  }

  let subtitle;

  if (advancedSearchCondition) {
    subtitle = _react.default.createElement("div", {
      className: _Subtitle.default.common
    }, _react.default.createElement(_AdvancedSearchBuilder.default, {
      condition: advancedSearchCondition,
      config: config,
      inline: true,
      readOnly: true,
      recordType: recordType
    }));
  }

  return _react.default.createElement("header", {
    className: _SearchToRelateTitleBar.default.common
  }, _react.default.createElement("h1", null, _react.default.createElement(_reactIntl.FormattedMessage, _extends({}, messages.title, {
    values: {
      collectionName,
      query: queryTitle
    }
  }))), subtitle);
}

SearchToRelateTitleBar.propTypes = propTypes;